OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
4. Rīcības plāns
5. Pārskats
6. Statuss 0%

# Risku novērtēšanas pielāgošana organizācijas vajadzībām

Lai pielāgotu riska novērtēšanu jūsu organizācijai, jums var lūgts veikt šādas darbības:

- Atlasīt vai izlaist situācijas, kas atbilst vai neatbilst jūsu uzņēmējdarbībai, un atzīmēt lodziņus, kas ir uz jums attiecināmi.
- Norādīt vairākas uzņēmuma struktūrvienības, filiāles, veikalus u.c. Šie saistītie riski tiks atkārtoti katram jūsu ievadītajam nosaukumam.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More